@@ -9,9 +9,9 @@ import inspect
 import base64
 from typing import Any, Union, Tuple
 
+from appium.webdriver.webdriver import WebDriver
 from selenium.common import NoSuchDriverException, InvalidSessionIdException
 
-
 # Configure the root logger (basic configuration)
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
@@ -29,14 +29,14 @@ class Terminal:
     Allows you to perform adb actions using the appium server. Useful for remote connections
     Required ssh
     """
-    base = None
-    transport = None
-    driver = None
+    base: "Shadowstep" = None
+    transport: "Transport" = None
+    driver: WebDriver = None
 
-    def __init__(self, base):
-        self.base = base
-        self.transport = base.transport
-        self.driver = base.driver
+    def __init__(self, base: "Shadowstep"):
+        self.base: "Shadowstep" = base
+        self.transport: "Transport" = base.transport
+        self.driver: WebDriver = base.driver
 
     def __del__(self):
         if self.transport is not None:
